Configuration
=============

:mod:`apax.config`

Training Configuration
----------------------

.. autoclass:: apax.config.train_config.Config
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.DataConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.ModelConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.OptimizerConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.MetricsConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.LossConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.CheckpointConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.TrainProgressbarConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.CSVCallback
    :members:
    :exclude-members: model_config  , model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.TBCallback
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.train_config.MLFlowCallback
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields



Molecular Dynamics Configuration
--------------------------------

.. autoclass:: apax.config.md_config.MDConfig
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields

.. autoclass:: apax.config.md_config.NPTOptions
    :members:
    :exclude-members: model_config, model_computed_fields, model_fields
